@@ -1,6 +1,4 @@
 """SatNOGS Network API permissions, django rest framework"""
-from __future__ import absolute_import
-
 from rest_framework import permissions
 
 from network.base.perms import schedule_perms
@@ -22,4 +20,4 @@ class StationOwnerPermission(permissions.BasePermission):
             return True
         if request.method == 'POST' and schedule_perms(request.user):
             return True
-        return request.user.is_authenticated() and request.user == obj.ground_station.owner
+        return request.user.is_authenticated and request.user == obj.ground_station.owner
