@@ -202,7 +202,6 @@ class NewObservationListSerializer(serializers.ListSerializer):
             transmitter_uuid = observation_data['transmitter_uuid']
             transmitter = self.transmitters[transmitter_uuid]
             tle_set = self.tle_sets[transmitter['norad_cat_id']]
-            print(tle_set, flush=True)
 
             observation = create_new_observation(
                 station=observation_data['ground_station'],
@@ -414,14 +413,29 @@ class JobSerializer(serializers.ModelSerializer):
     mode = serializers.SerializerMethodField()
     transmitter = serializers.SerializerMethodField()
     baud = serializers.SerializerMethodField()
+    tle0 = serializers.SerializerMethodField()
+    tle1 = serializers.SerializerMethodField()
+    tle2 = serializers.SerializerMethodField()
 
     class Meta:
         model = Observation
         fields = (
-            'id', 'start', 'end', 'ground_station', 'tle_line_0', 'tle_line_1', 'tle_line_2',
-            'frequency', 'mode', 'transmitter', 'baud'
+            'id', 'start', 'end', 'ground_station', 'tle0', 'tle1', 'tle2', 'frequency', 'mode',
+            'transmitter', 'baud'
         )
 
+    def get_tle0(self, obj):
+        """Returns tle0"""
+        return obj.tle_line_0
+
+    def get_tle1(self, obj):
+        """Returns tle1"""
+        return obj.tle_line_1
+
+    def get_tle2(self, obj):
+        """Returns tle2"""
+        return obj.tle_line_2
+
     def get_frequency(self, obj):
         """Returns Transmitter downlink low frequency"""
         frequency = obj.transmitter_downlink_low
